==> kdepim-addons-17.04.1.tar.xz: kdepim-addons-17.04.1/plugins/messageviewerplugins/common/expandurlplugin/viewerpluginexpandurl.cpp <==
/*
   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "viewerpluginexpandurl.h"
#include "viewerpluginexpandurlinterface.h"
#include <KActionCollection>
#include <kpluginfactory.h>

using namespace MessageViewer;
K_PLUGIN_FACTORY_WITH_JSON(ViewerPluginExpandurlFactory, "messageviewer_expandurlplugin.json", registerPlugin<ViewerPluginExpandurl>();)

ViewerPluginExpandurl::ViewerPluginExpandurl(QObject *parent, const QList<QVariant> &)
    : MessageViewer::ViewerPlugin(parent)
{

}

ViewerPluginInterface *ViewerPluginExpandurl::createView(QWidget *parent, KActionCollection *ac)
{
    MessageViewer::ViewerPluginInterface *view = new MessageViewer::ViewerPluginExpandurlInterface(ac, parent);
    return view;
}

QString ViewerPluginExpandurl::viewerPluginName() const
{
    return QStringLiteral("expandurl");
}

#include "viewerpluginexpandurl.moc"

==> kdepim-addons-17.07.80.tar.xz: kdepim-addons-17.07.80/plugins/messageviewerplugins/common/expandurlplugin/viewerpluginexpandurl.cpp <==
/*
   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "viewerpluginexpandurl.h"
#include "viewerpluginexpandurlinterface.h"
#include <KActionCollection>
#include <kpluginfactory.h>

using namespace MessageViewer;
K_PLUGIN_FACTORY_WITH_JSON(ViewerPluginExpandurlFactory, "messageviewer_expandurlplugin.json", registerPlugin<ViewerPluginExpandurl>();
                           )

ViewerPluginExpandurl::ViewerPluginExpandurl(QObject *parent, const QList<QVariant> &)
    : MessageViewer::ViewerPlugin(parent)
{
}

ViewerPluginInterface *ViewerPluginExpandurl::createView(QWidget *parent, KActionCollection *ac)
{
    MessageViewer::ViewerPluginInterface *view = new MessageViewer::ViewerPluginExpandurlInterface(ac, parent);
    return view;
}

QString ViewerPluginExpandurl::viewerPluginName() const
{
    return QStringLiteral("expandurl");
}

#include "viewerpluginexpandurl.moc"
